package es.uca.xmleye.util;

/*
 Copyright (C) 2005-2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA
 */

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;

/**
 * Tarea que vuelca todos los bytes de la entrada en la salida.
 */
public class TareaVolcado implements TareaEntrada {
	private InputStream is;
	private OutputStream os;

	/**
	 * Crea un nuevo TareaVolcado que volcará a <code>os</code>.
	 * 
	 * @param os
	 *            Flujo de salida.
	 */
	public TareaVolcado(OutputStream os) {
		this.os = os;
	}

	/**
	 * Crea un nuevo TareaVolcado que volcará al fichero <code>fich</code>.
	 * 
	 * Método de conveniencia para <code>TareaVolcado(OutputStream)</code>.
	 * 
	 * @param fich
	 *            Fichero de salida.
	 */
	public TareaVolcado(File fich) throws FileNotFoundException {
		this.os = new BufferedOutputStream(new FileOutputStream(fich));
	}

	public void setFlujoEntrada(InputStream is) {
		this.is = is;
	}

	/**
	 * Vuelca todo el contenido de un flujo en otro, tras lo cual cierra ambos.
	 * 
	 * @return Número total de bytes leídos.
	 * @throws IOException
	 *             Fallo de E/S.
	 */
	public Integer call() throws Exception {
		byte[] buf = new byte[256];
		int bytesLeidos = 0;
		int bytesTotal = 0;

		while ((bytesLeidos = is.read(buf, 0, buf.length)) != -1) {
			bytesTotal += bytesLeidos;
			os.write(buf, 0, bytesLeidos);
		}

		is.close();
		os.flush();
		os.close();

		return new Integer(bytesTotal);
	}
}
