package es.uca.xmleye.util;

import java.io.IOException;
import java.io.OutputStream;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Node;

/** 
 * Clase con un único método de utilidad para volcar un árbol XML a la salida estándar.
 * */
public class VolcadorXML {
	
	/**
	 * Vuelca un árbol DOM a un fichero a través de la transformación XSLT por
	 * defecto.
	 * 
	 * @throws TransformerFactoryConfigurationError
	 *             Fallo al configurar el transformador.
	 * @throws TransformerException
	 *             Fallo al serializar a disco el árbol XML.
	 * @throws IOException
	 *             Fallo de E/S.
	 * @throws ParserConfigurationException
	 */
	public static void volcarXML(Node n, OutputStream os)
			throws TransformerFactoryConfigurationError, TransformerException,
			IOException, ParserConfigurationException {
		DOMSource origen = new DOMSource(n.getOwnerDocument());
		StreamResult destino = new StreamResult(os);

		Transformer serializador = TransformerFactory.newInstance()
				.newTransformer();
		serializador.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
		serializador.setOutputProperty(OutputKeys.INDENT, "yes");
		serializador.transform(origen, destino);
	}

}
